powered by
coxtv
coxtp
The baseline estimation is the baseline hazard at each observed failure time when holding all the covariates to be zero.
baseline(fit)
A list with three components:
the unique observed failure times.
the baseline hazard corresponding to each unique failure time point.
the cumulative baseline hazard corresponding to each unique failure time point.
model from coxtv or coxtp.
data(ExampleData) z <- ExampleData$z time <- ExampleData$time event <- ExampleData$event fit <- coxtv(event = event, z = z, time = time) base.est <- baseline(fit)
Run the code above in your browser using DataLab