Learn R Programming

surtvep (version 1.0.0)

confint.coxtp: get confidence intervals of time-varying coefficients from a fitted object

Description

Get confidence intervals of time-varying coefficients from a fitted coxtv or coxtp object.

Usage

# S3 method for coxtp
confint(object, parm, level = 0.95, time, ...)

# S3 method for coxtv confint(object, parm, level = 0.95, time, ...)

Value

A list where each element corresponds to one of the parameters specified in parm. Each element in the list is a matrix, with rows corresponding to the specified time points and three columns representing the estimated values of the parameter, and the lower and upper bounds of the confidence interval at the specified confidence level. The length of the list is determined by the number of parameters in parm, and each matrix has rows equal to the number of specified time points.

A list where each element corresponds to one of the parameters specified in parm. Each element in the list is a matrix, with rows corresponding to the specified time points and three columns representing the estimated values of the parameter, and the lower and upper bounds of the confidence interval at the specified confidence level. The length of the list is determined by the number of parameters in parm, and each matrix has rows equal to the number of specified time points.

Arguments

object

fitted "coxtv" model.

parm

the names of parameters.

level

the confidence level. The default value is 0.95.

time

the time points for which the confidence intervals to be estimated. The default value is the unique observed event times in the dataset fitting the time-varying effects model.

...

other parameters to function

Examples

Run this code
# \donttest{
data(ExampleData)
z <- ExampleData$z
time <- ExampleData$time
event <- ExampleData$event
fit <- coxtp(event = event, z = z, time = time)
IC  <- IC(fit)
confint(IC$model.mAIC)
# }

data(ExampleData)
z <- ExampleData$z
time <- ExampleData$time
event <- ExampleData$event
fit <- coxtv(event = event, z = z, time = time)
confint <- confint(fit)

Run the code above in your browser using DataLab