Learn R Programming

surtvep (version 1.0.0)

tvef.ph: testing the proportional hazards assumption from a coxtv or coxtp object

Description

Testing the proportional hazards assumption using a Wald test statistic.

Usage

tvef.ph(fit, parm)

Value

tvef.ph produces a matrix. Each row corresponds to a covariate from the fitted object. The three columns give the test statistic, degrees of freedom and P-value.

Arguments

fit

fitted coxtv or coxtp model.

parm

the names of parameters to be tested.

See Also

tvef.zero tvef.zero.time

Examples

Run this code
data(ExampleData)
z <- ExampleData$z
time <- ExampleData$time
event <- ExampleData$event
fit <- coxtv(event = event, z = z, time = time)
tvef.ph(fit)

Run the code above in your browser using DataLab