tvef.zero.time: testing the significance of the covariates from a coxtv or coxtp object using a Wald test statistic
Description
Testing the significance of the covariates at each time point.
Usage
tvef.zero.time(fit, time, parm)
Value
tvef.zero.time produces a list of length nvars. Each element of the list is a matrix with respect to a
covariate. The matrix is of dimension len_unique_t by 4, where len_unique_t is the length of unique observed event time.
Each row corresponds to the testing result at that time. The four
columns give the estimations, standard error, test-statistic and P-value.
Arguments
fit
fitted coxtv or coxtp model.
time
the time points to test if the covariate is significant or not.
data(ExampleData)
z <- ExampleData$z
time <- ExampleData$time
event <- ExampleData$event
fit <- coxtv(event = event, z = z, time = time)
test <- tvef.zero.time(fit)