A list where each element corresponds to one of the parameters specified in parm. Each element in the
list is a matrix, with rows corresponding to the specified time points and three columns representing the
estimated values of the parameter, and the lower and upper bounds of the confidence interval at the specified
confidence level. The length of the list is determined by the number of parameters in parm, and each matrix
has rows equal to the number of specified time points.
A list where each element corresponds to one of the parameters specified in parm. Each element in the
list is a matrix, with rows corresponding to the specified time points and three columns representing the
estimated values of the parameter, and the lower and upper bounds of the confidence interval at the specified
confidence level. The length of the list is determined by the number of parameters in parm, and each matrix
has rows equal to the number of specified time points.