tvef.ph: testing the proportional hazards assumption from a coxtv or coxtp object
Description
Testing the proportional hazards assumption using a Wald test statistic.
Usage
tvef.ph(fit, parm)
Value
tvef.ph produces a matrix. Each row corresponds to a covariate from the fitted object. The three
columns give the test statistic, degrees of freedom and P-value.